@@ -26,5 +26,5 @@ class Timer:
 
         elapsed_time = time.perf_counter() - self._start_time
         self._start_time = None
-        print(f"Elapsed time: {elapsed_time:0.4f} seconds")
+        print(f"Elapsed time: {int(elapsed_time)} seconds")
         return elapsed_time
